@@ -2,13 +2,13 @@
 from jsonvl.constants.builtins import Primitive
 from jsonvl.constants.reserved import Reserved
 from jsonvl.core._number.number_constraints import NumberConstraints
-from jsonvl.errors import JsonValidationError, ErrorMessages
+from jsonvl.errors import ErrorMessages, JsonSchemaError, JsonValidationError
 
 
 TYPE_NAME = Primitive.NUMBER.value
 
 
-def validate_number(data, schema, path):
+def validate_number(data, schema, defs, path):
     """
     Validate a JSON number based on a schema.
 
@@ -25,8 +25,8 @@ def validate_number(data, schema, path):
         type_constraints = schema[Reserved.CONSTRAINTS]
         for cons_name, cons_param in type_constraints.items():
             if not NumberConstraints.has(cons_name):
-                raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT,
-                                                 type=TYPE_NAME, cons=cons_name)
+                raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT,
+                                             type=TYPE_NAME, cons=cons_name)
 
             if cons_name == NumberConstraints.LT.value:
                 _constrain_lt(cons_name, data, cons_param, path)
@@ -39,14 +39,14 @@ def validate_number(data, schema, path):
             elif cons_name == NumberConstraints.EQ.value:
                 _constrain_eq(cons_name, data, cons_param, path)
             else:
-                raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT,
-                                                 type=TYPE_NAME, cons=cons_name)
+                raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT,
+                                             type=TYPE_NAME, cons=cons_name)
 
 
 def _check_type(cons_name, cons_param):
     if not isinstance(cons_param, (int, float)):
-        raise JsonValidationError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM,
-                                         cons=cons_name, param_types=[Primitive.NUMBER.value], param=cons_param)
+        raise JsonSchemaError.create(ErrorMessages.INVALID_CONSTRAINT_PARAM_TYPE,
+                                     cons=cons_name, param_types=[Primitive.NUMBER.value], param=cons_param)
 
 
 def _constrain_lt(cons_name, data, cons_param, path):
