@@ -1,5 +1,5 @@
 """String constraints."""
-from jsonvl.utilities.venum import Venum
+from jsonvl._utilities.venum import Venum
 
 
 class StringConstraints(Venum):
